\name{NelPlo}
\alias{NelPlo}
\alias{cpi}
\alias{ip}
\alias{gnp.nom}
\alias{vel}
\alias{emp}
\alias{int.rate}
\alias{nom.wages}
\alias{gnp.def}
\alias{money.stock}
\alias{gnp.real}
\alias{stock.prices}
\alias{gnp.capita}
\alias{real.wages}
\alias{unemp}
\title{
  Nelson--Plosser Macroeconomic Time Series
}
\description{
  These are the extended Nelson-Plosser Data. 
}
\usage{
data(NelPlo)
}
\format{
  14 macroeconomic time series: \code{cpi}, \code{ip}, \code{gnp.nom},
  \code{vel}, \code{emp}, \code{int.rate}, \code{nom.wages},
  \code{gnp.def}, \code{money.stock}, \code{gnp.real},
  \code{stock.prices}, \code{gnp.capita}, \code{real.wages}, and
  \code{unemp} and the joint series \code{NelPlo}.
}
\details{
  The series are of various lengths but all end in 1988.
  The data set contains the following series:
  consumer price index, industrial production, nominal GNP, velocity,
  employment, interest rate, nominal wages, GNP deflator, money stock,
  real GNP, stock prices (S&P500), GNP per capita, real wages,
  unemployment.
}
\source{
  Journal of Business and Economic Statistics data archive
  \url{http://www.amstat.org/publications/jbes/}
}
\references{
  G. Koop and M. F. J. Steel (1994): A Decision-Theoretic Analysis of
  the Unit-Root Hypothesis using Mixtures of Elliptical Models.
  \emph{Journal of Business and Economic Statistics}, \bold{12},
  95--107.
}
\keyword{datasets}

\eof
\name{USeconomic}
\alias{USeconomic}
\alias{M1}
\alias{GNP}
\alias{rs}
\alias{rl}
\title{
  U.S. Economic Variables
}
\description{
  This is the E.3 example data set of Luetkepohl (1991).
}
\usage{
data(USeconomic)
}
\format{
  4 univariate time series \code{M1}, \code{GNP}, \code{rs}, and
  \code{rl} and the joint series \code{USeconomic} containing the
  logarithm of \code{M1}, the logarithm of \code{GNP}, \code{rs}, and
  \code{rl}.
}
\details{
  It contains seasonally adjusted real U.S. money \code{M1} and GNP in
  1982 Dollars; discount rate on 91-Day treasury bills \code{rs} and
  yield on long-term treasury bonds \code{rl}. 
}
\source{
  Luetkepohl, H. (1991):
  \emph{Introduction to Multiple Time Series Analysis}.
  Springer Verlag, NY, 500--503.
}
\keyword{datasets}

\eof
\name{adf.test}
\alias{adf.test}
\title{Augmented Dickey--Fuller Test}
\description{
  Computes the Augmented Dickey-Fuller test for the null that \code{x} has
  a unit root.
}
\usage{
adf.test(x, alternative = c("stationary", "explosive"),
         k = trunc((length(x)-1)^(1/3)))
}
\arguments{
  \item{x}{a numeric vector or time series.}
  \item{alternative}{indicates the alternative hypothesis and must be
    one of \code{"stationary"} (default) or \code{"explosive"}. You can
    specify just the initial letter.}
  \item{k}{the lag order to calculate the test statistic.}
}
\details{
  The general regression equation which incorporates a constant and a
  linear trend is used and the t-statistic for a first order
  autoregressive coefficient equals one is computed. The number of lags
  used in the regression is \code{k}. The default value of
  \code{trunc((length(x)-1)^(1/3))} corresponds to the suggested upper
  bound on the rate at which the number of lags, \code{k}, should be
  made to grow with the sample size for the general \code{ARMA(p,q)}
  setup. Note that for \code{k} equals zero the standard Dickey-Fuller
  test is computed. The p-values are interpolated from Table 4.2, p. 103
  of Banerjee et al. (1993). If the computed statistic is outside the
  table of critical values, then a warning message is generated. 
  
  Missing values are not allowed.
}
\value{
  A list with class \code{"htest"} containing the following components:
  \item{statistic}{the value of the test statistic.}
  \item{parameter}{the lag order.}
  \item{p.value}{the p-value of the test.}
  \item{method}{a character string indicating what type of test was
    performed.} 
  \item{data.name}{a character string giving the name of the data.}
  \item{alternative}{a character string describing the alternative
    hypothesis.}
}
\references{
  A. Banerjee, J. J. Dolado, J. W. Galbraith, and D. F. Hendry (1993):
  \emph{Cointegration, Error Correction, and the Econometric Analysis of
    Non-Stationary Data},
  Oxford University Press, Oxford.
  
  S. E. Said and D. A. Dickey (1984):
  Testing for Unit Roots in Autoregressive-Moving Average Models of
  Unknown Order.
  \emph{Biometrika} \bold{71}, 599--607.
}
\author{A. Trapletti}
\seealso{
  \code{\link{pp.test}}
}
\examples{
x <- rnorm(1000)  # no unit-root
adf.test(x)

y <- diffinv(x)   # contains a unit-root
adf.test(y)
}
\keyword{ts}

\eof
\name{arma-methods}
\alias{arma-methods}
\alias{coef.arma}
\alias{residuals.arma}
\alias{fitted.arma}
\alias{print.arma}
\alias{plot.arma}
\title{Methods for Fitted ARMA Models}
\description{
  Methods for fitted ARMA model objects.
}
\usage{
\method{coef}{arma}(object, \dots)
\method{residuals}{arma}(object, \dots)
\method{fitted}{arma}(object, \dots)
\method{print}{arma}(x, digits = max(3, getOption("digits") - 3), \dots)
\method{plot}{arma}(x, ask = interactive(), \dots)
}
\arguments{
  \item{object, x}{an object of class \code{"arma"}; usually, a result
    of a call to \code{\link{arma}}.}
  \item{digits}{see \code{\link{printCoefmat}}.}
  \item{ask}{Should the \code{plot} method work interactively?  See
    \code{\link{interactive}}.}
  \item{\dots}{further arguments passed to or from other methods.} 
}
\value{
  For \code{coef}, a numeric vector;
  for \code{residuals} and \code{fitted} a univariate time series;
  for \code{plot} and \code{print}, the fitted ARMA model object.
}
\author{
  A. Trapletti
}
\seealso{
  \code{\link{arma}}
}
\keyword{models}
\keyword{ts}

\eof
\name{arma}
\alias{arma}
\title{Fit ARMA Models to Time Series}
\description{
  Fit an ARMA model to a univariate time series by conditional least
  squares.  For exact maximum likelihood estimation see
  \code{\link{arima0}}. 
}
\usage{
arma(x, order = c(1, 1), lag = NULL, coef = NULL,
     include.intercept = TRUE, series = NULL, qr.tol = 1e-07, \dots)
}
\arguments{
  \item{x}{a numeric vector or time series.}
  \item{order}{a two dimensional integer vector giving the orders of the
    model to fit. \code{order[1]} corresponds to the AR part and
    \code{order[2]} to the MA part.}
  \item{lag}{a list with components \code{ar} and \code{ma}. Each
    component is an integer vector, specifying the AR and MA lags that are
    included in the model. If both, \code{order} and \code{lag}, are
    given, only the specification from \code{lag} is used.}
  \item{coef}{If given this numeric vector is used as the initial estimate
    of the ARMA coefficients. The preliminary estimator suggested in
    Hannan and Rissanen (1982) is used for the default initialization.}
  \item{include.intercept}{Should the model contain an intercept?}
  \item{series}{name for the series. Defaults to
    \code{deparse(substitute(x))}.}
  \item{qr.tol}{the \code{tol} argument for \code{\link{qr}} when computing
    the asymptotic standard errors of \code{coef}.}
  \item{\dots}{additional arguments for \code{\link{optim}} when fitting
    the model.}
}
\details{
  The following parametrization is used for the ARMA(p,q) model:
  
  \deqn{y[t] = a[0] + a[1]y[t-1] + \dots + a[p]y[t-p] + b[1]e[t-1] +
    \dots + b[q]e[t-q] + e[t],}
  
  where \eqn{a[0]} is set to zero if no intercept is included. By using
  the argument \code{lag}, it is possible to fit a parsimonious submodel
  by setting arbitrary \eqn{a[i]} and \eqn{b[i]} to zero.
  
  \code{arma} uses \code{\link{optim}} to minimize the conditional
  sum-of-squared errors. The gradient is computed, if it is needed, by
  a finite-difference approximation. Default initialization is done by
  fitting a pure high-order AR model (see \code{\link{ar.ols}}). 
  The estimated residuals are then used for computing a least squares
  estimator of the full ARMA model. See Hannan and Rissanen (1982) for
  details.
}
\value{
  A list of class \code{"arma"} with the following elements:
  \item{lag}{the lag specification of the fitted model.}
  \item{coef}{estimated ARMA coefficients for the fitted model.}
  \item{css}{the conditional sum-of-squared errors.}
  \item{n.used}{the number of observations of \code{x}.}
  \item{residuals}{the series of residuals.}
  \item{fitted.values}{the fitted series.}
  \item{series}{the name of the series \code{x}.}
  \item{frequency}{the frequency of the series \code{x}.}
  \item{call}{the call of the \code{arma} function.}
  \item{asy.se.coef}{the asymptotic-theory standard errors of the
    coefficient estimates.}
  \item{convergence}{The \code{convergence} integer code from
    \code{\link{optim}}.}
  \item{include.intercept}{Does the model contain an intercept?}
}
\references{
  E. J. Hannan and J. Rissanen (1982):
  Recursive Estimation of Mixed Autoregressive-Moving Average
  Order.
  \emph{Biometrika} \bold{69}, 81--94. 
}
\author{
  A. Trapletti
}
\seealso{
  \code{\link{summary.arma}} for summarizing ARMA model fits;
  \code{\link{arma-methods}} for further methods;
  \code{\link{arima0}}, \code{\link{ar}}.
}
\examples{
data(tcm)  
r <- diff(tcm10y)
summary(r.arma <- arma(r, order = c(1, 0)))
summary(r.arma <- arma(r, order = c(2, 0)))
summary(r.arma <- arma(r, order = c(0, 1)))
summary(r.arma <- arma(r, order = c(0, 2)))
summary(r.arma <- arma(r, order = c(1, 1)))
plot(r.arma)

data(nino)
s <- nino3.4
summary(s.arma <- arma(s, order=c(20,0)))
summary(s.arma
         <- arma(s, lag=list(ar=c(1,3,7,10,12,13,16,17,19),ma=NULL)))
acf(residuals(s.arma), na.action=na.remove)
pacf(residuals(s.arma), na.action=na.remove)
summary(s.arma
         <- arma(s, lag=list(ar=c(1,3,7,10,12,13,16,17,19),ma=12)))
summary(s.arma
         <- arma(s, lag=list(ar=c(1,3,7,10,12,13,16,17),ma=12)))
plot(s.arma)
}
\keyword{ts}

\eof
\name{bds.test}
\alias{bds.test}
\alias{print.bdstest}
\title{BDS Test}
\description{
  Computes and prints the BDS test statistic for the null that \code{x}
  is a series of i.i.d. random variables.
}
\usage{
bds.test(x, m = 3, eps = seq(0.5 * sd(x), 2 * sd(x), length = 4),
         trace = FALSE)
}
\arguments{
  \item{x}{a numeric vector or time series.}
  \item{m}{an integer indicating that the BDS test statistic is computed
    for embedding dimensions \code{2}, \dots, \code{m}.}
  \item{eps}{a numeric vector of epsilon values for close points.  The
    BDS test is computed for each element of \code{eps}.  It should be
    set in terms of the standard deviation of \code{x}.}
  \item{trace}{a logical indicating whether some informational output is
    traced.}
}
\details{
  This test examines the ``spatial dependence'' of the observed
  series.  To do this, the series is embedded in \code{m}-space and the
  dependence of \code{x} is examined by counting ``near'' points.
  Points for which the distance is less than \code{eps} are called
  ``near''.  The BDS test statistic is asymptotically standard Normal.
  
  Missing values are not allowed.

  There is a special print method for objects of class \code{"bdstest"}
  which by default uses 4 digits to format real numbers.
}
\value{
  A list with class \code{"bdstest"} containing the following components:
  \item{statistic}{the values of the test statistic.}
  \item{p.value}{the p-values of the test.}
  \item{method}{a character string indicating what type of test was
    performed.}
  \item{parameter}{a list with the components \code{m} and \code{eps}
    containing the embedding dimensions and epsilon values for which the
    statistic is computed.}
  \item{data.name}{a character string giving the name of the data.}
}
\references{
  J. B. Cromwell, W. C. Labys and M. Terraza (1994):
  \emph{Univariate Tests for Time Series Models},
  Sage, Thousand Oaks, CA, pages 32--36.
}
\author{B. LeBaron, Ported to R by A. Trapletti}
\examples{
x <- rnorm(100)
bds.test(x)  # i.i.d. example

x <- c(rnorm(50), runif(50))
bds.test(x)  # not identically distributed

x <- quadmap(xi = 0.2, a = 4.0, n = 100)
bds.test(x)  # not independent
}
\keyword{ts}

\eof
\name{bev}
\alias{bev}
\title{
  Beveridge Wheat Price Index, 1500--1869.
}
\description{
  Contains the well-known Beveridge Wheat Price Index which gives annual
  price data from 1500 to 1869, averaged over many locations in western
  and central Europe.
}
\usage{
data(bev)
}
\format{
  A univariate time series with 370 observations.  The object is of
  class \code{"ts"}.
}
\details{
  This data provides an example of long memory time series which has the
  appearance of being nonstationary in levels and yet also appears
  overdifferenced.  See, e.g., Baillie (1996).
}
\source{
  Time Series Data Library:
  \url{http://www-personal.buseco.monash.edu.au/~hyndman/TSDL/}
}
\references{
  R. T. Baillie (1996):
  Long Memory Processes and Fractional Integration in Econometrics.
  \emph{Journal of Econometrics}, \bold{73}, 5--59.
}
\keyword{datasets}

\eof
\name{camp}
\alias{camp}
\title{
  Mount Campito Yearly Treering Data, -3435--1969.
}
\description{
  Contains annual tree-ring measurements from Mount Campito from 3426 BC
  through 1969 AD.
}
\usage{
data(camp)
}
\format{
  A univariate time series with 5405 observations. The object is of
  class \code{"ts"}.
}
\details{
  This series is a standard example for the concept of long memory time
  series.

  The data was produced and assembled at the Tree Ring Laboratory at the
  University of Arizona, Tuscon.
}
\source{
  Time Series Data Library:
  \url{http://www-personal.buseco.monash.edu.au/~hyndman/TSDL/}
}
\keyword{datasets}

\eof
\name{garch-methods}
\alias{garch-methods}
\alias{predict.garch}
\alias{coef.garch}
\alias{residuals.garch}
\alias{fitted.garch}
\alias{print.garch}
\alias{plot.garch}
\alias{logLik.garch}
\title{Methods for Fitted GARCH Models}
\description{
  Methods for fitted GARCH model objects.
}
\usage{
\method{predict}{garch}(object, newdata, genuine = FALSE, \dots)
\method{coef}{garch}(object, \dots)
\method{residuals}{garch}(object, \dots)
\method{fitted}{garch}(object, \dots)
\method{print}{garch}(x, digits = max(3, getOption("digits") - 3), \dots)
\method{plot}{garch}(x, ask = interactive(), \dots)
\method{logLik}{garch}(object, \dots)
}
\arguments{
  \item{object, x}{an object of class \code{"garch"}; usually, a result
    of a call to \code{\link{garch}}.}
  \item{newdata}{a numeric vector or time series to compute GARCH
    predictons.  Defaults to \code{eval(parse(text=object$series))}.}
  \item{genuine}{a logical indicating whether a genuine prediction
    should be made, i.e., a prediction for which there is no target
    observation available.}
  \item{digits}{see \code{\link{printCoefmat}}.}
  \item{ask}{Should the \code{plot} method work interactively?  See
    \code{\link{interactive}}.}
  \item{\dots}{further arguments passed to or from other methods.} 
}
\details{
  \code{predict} returns +/- the conditional standard deviation
  predictions from a fitted GARCH model.

  \code{coef} returns the coefficient estimates.

  \code{residuals} returns the GARCH residuals, i.e., the time series
  used to fit the model divided by the computed conditional standard
  deviation predictions for this series. Under the assumption of
  conditional normality the residual series should be i.i.d. standard
  normal.  

  \code{fitted} returns +/- the conditional standard deviation
  predictions for the series which has been used to fit the model.

  \code{plot} graphically investigates normality and remaining ARCH
  effects for the residuals.

  \code{logLik} returns the log-likelihood value of the GARCH(p, q)
  model represented by \code{object} evaluated at the estimated
  coefficients. It is assumed that first max(p, q) values are fixed.
}  
\value{
  For \code{predict} a bivariate time series (two-column matrix) of
  predictions. 
  
  For \code{coef}, a numeric vector, for \code{residuals} and
  \code{fitted} a univariate (vector) and a bivariate time series
  (two-column matrix), respectively.

  For \code{plot} and \code{print}, the fitted GARCH model object.
}
\author{
  A. Trapletti
}
\keyword{models}
\keyword{ts}

\eof
\name{garch}
\alias{garch}
\title{Fit GARCH Models to Time Series}
\description{
  Fit a Generalized Autoregressive Conditional Heteroscedastic GARCH(p,
  q) time series model to the data by computing the maximum-likelihood
  estimates of the conditionally normal model.
}
\usage{
garch(x, order = c(1, 1), coef = NULL, itmax = 200, eps = NULL,
      grad = c("analytical","numerical"), series = NULL,
      trace = TRUE, \dots)
}
\arguments{
  \item{x}{a numeric vector or time series.}
  \item{order}{a two dimensional integer vector giving the orders of the
    model to fit.  \code{order[2]} corresponds to the ARCH part and
    \code{order[1]} to the GARCH part.}
  \item{coef}{If given this numeric vector is used as the initial estimate
    of the GARCH coefficients.  Default initialization is to set the
    GARCH parameters to slightly positive values and to initialize the
    intercept such that the unconditional variance of the initial GARCH
    is equal to the variance of \code{x}.}
  \item{itmax}{gives the maximum number of log-likelihood function
    evaluations \code{itmax} and the maximum number of iterations
    \code{2*itmax} the optimizer is allowed to compute.}
  \item{eps}{defines the absolute (\code{max(1e-20, eps^2)}) and
    relative function convergence tolerance
    (\code{max(1e-10, eps^(2/3))}), the coefficient-convergence
    tolerance (\code{sqrt(eps)}), and the false convergence tolerance
    (\code{1e2*eps}). Default value is the machine epsilon, see
    \code{\link{Machine}}.}
  \item{grad}{indicates if the analytical gradient or a numerical
    approximation is used for the optimization.}
  \item{series}{name for the series. Defaults to
    \code{deparse(substitute(x))}.}
  \item{trace}{trace optimizer output?}
  \item{\dots}{additional arguments for \code{\link{qr}} when computing
    the asymptotic standard errors of \code{coef}.}
}
\details{
  \code{garch} uses a Quasi-Newton optimizer to find the maximum
  likelihood estimates of the conditionally normal model.  The first
  max(p, q) values are assumed to be fixed.  The optimizer uses a hessian
  approximation computed from the BFGS update.  Only a Cholesky factor
  of the Hessian approximation is stored.  For more details see Dennis
  et al. (1981), Dennis and Mei (1979), Dennis and More (1977), and
  Goldfarb (1976).  The gradient is either computed analytically or
  using a numerical approximation.
}
\value{
  A list of class \code{"garch"} with the following elements:
  \item{order}{the order of the fitted model.}
  \item{coef}{estimated GARCH coefficients for the fitted model.}
  \item{n.likeli}{the negative log-likelihood function evaluated at the
    coefficient estimates (apart from some constant).}
  \item{n.used}{the number of observations of \code{x}.}
  \item{residuals}{the series of residuals.}
  \item{fitted.values}{the bivariate series of conditional standard
    deviation predictions for \code{x}.}
  \item{series}{the name of the series \code{x}.}
  \item{frequency}{the frequency of the series \code{x}.}
  \item{call}{the call of the \code{garch} function.}
  \item{asy.se.coef}{the asymptotic-theory standard errors of the
    coefficient estimates.}
}
\references{
  A. K. Bera and M. L. Higgins (1993):
  ARCH Models: Properties, Estimation and Testing.
  \emph{J. Economic Surveys} \bold{7} 305--362.
  
  T. Bollerslev (1986):
  Generalized Autoregressive Conditional Heteroscedasticity.
  \emph{Journal of Econometrics} \bold{31}, 307--327.

  R. F. Engle (1982):
  Autoregressive Conditional Heteroscedasticity with Estimates of the
  Variance of United Kingdom Inflation.
  \emph{Econometrica} \bold{50}, 987--1008.

  J. E. Dennis, D. M. Gay, and R. E. Welsch (1981):
  Algorithm 573 --- An Adaptive Nonlinear Least-Squares
  Algorithm.
  \emph{ACM Transactions on Mathematical Software} \bold{7}, 369--383.

  J. E. Dennis and H. H. W. Mei (1979):
  Two New Unconstrained Optimization Algorithms which use Function and
  Gradient Values.
  \emph{J. Optim. Theory Applic.} \bold{28}, 453--482.

  J. E. Dennis and J. J. More (1977):
  Quasi-Newton Methods, Motivation and Theory.
  \emph{SIAM Rev.} \bold{19}, 46--89.

  D. Goldfarb (1976):
  Factorized Variable Metric Methods for Unconstrained Optimization.
  \emph{Math. Comput.} \bold{30}, 796--811.
}
\author{
  A. Trapletti, the whole GARCH part;
  D. M. Gay, the FORTRAN optimizer
}
\seealso{
  \code{\link{summary.garch}} for summarizing GARCH model fits;
  \code{\link{garch-methods}} for further methods.
}
\examples{
n <- 1100
a <- c(0.1, 0.5, 0.2)  # ARCH(2) coefficients
e <- rnorm(n)  
x <- double(n)
x[1:2] <- rnorm(2, sd = sqrt(a[1]/(1.0-a[2]-a[3]))) 
for(i in 3:n)  # Generate ARCH(2) process
{
  x[i] <- e[i]*sqrt(a[1]+a[2]*x[i-1]^2+a[3]*x[i-2]^2)
}
x <- ts(x[101:1100])
x.arch <- garch(x, order = c(0,2))  # Fit ARCH(2) 
summary(x.arch)                     # Diagnostic tests
plot(x.arch)                        

data(EuStockMarkets)  
dax <- diff(log(EuStockMarkets))[,"DAX"]
dax.garch <- garch(dax)  # Fit a GARCH(1,1) to DAX returns
summary(dax.garch)       # ARCH effects are filtered. However, 
plot(dax.garch)          # conditional normality seems to be violated
}
\keyword{ts}

\eof
\name{get.hist.quote}
\alias{get.hist.quote}
\title{Download Historical Finance Data}
\description{
  Download historical financial data from a given data provider over
  the WWW.
}
\usage{
get.hist.quote(instrument = "^gdax", start, end,
               quote = c("Open", "High", "Low", "Close"),
               provider = "yahoo", method = "auto",
               origin = "1899-12-30") 
}
\arguments{
  \item{instrument}{a character string giving the name of the quote
    symbol to download.  See the web page of the data provider for
    information about the available quote symbols.}
  \item{start}{an R object specifying the date of the start of the
    period to download.  This must be in a form which is recognized by
    \code{\link{as.POSIXct}}, which includes R POSIX date/time objects,
    objects of class \code{"date"} (from package \code{date}) and
    \code{"chron"} and \code{"dates"} (from package \code{chron}), and
    character strings representing dates in ISO 8601 format.  Defaults
    to 1992-01-02.}
  \item{end}{an R object specifying the end of the download period, see
    above.  Defaults to yesterday.}
  \item{quote}{a character string or vector indicating whether to
    download opening, high, low, or closing quotes, or volume.  For the
    default provider, this can be specified as \code{"Open"},
    \code{"High"}, \code{"Low"}, \code{"Close"}, and \code{"Volume"},
    respectively.  Abbreviations are allowed.}
  \item{provider}{a character string with the name of the data
    provider.  Currently, only \code{"yahoo"} is implemented.  See
    \url{http://quote.yahoo.com/} for more information.}
  \item{method}{tool to be used for downloading the data.  See
    \code{\link{download.file}} for the available download methods.}
  \item{origin}{an R object specifying the origin of the Julian dates, see
    above.  Defaults to 1899-12-30 (Popular spreadsheet programs
    internally also use Julian dates with this origin).}
}
\value{
  A time series containing the data in physical time, i.e., weekends,
  holidays, and missing days are filled with \code{NA}s.  The time scale
  is given in Julian dates (days since the \code{origin}). 
}
\author{A. Trapletti}
\seealso{
  \code{\link{ts}},
  \code{\link{as.POSIXct}},
  \code{\link{download.file}};
  \url{http://quote.yahoo.com/} 
}
\examples{
\dontrun{
x <- get.hist.quote(instrument = "^spc", start = "1998-01-01",
                    quote = "Close")
plot(x)

x <- get.hist.quote(instrument = "ibm", quote = c("Cl", "Vol"))
plot(x, main = "International Business Machines Corp")

spc <- get.hist.quote(instrument = "^spc", start = "1998-01-01")
ibm <- get.hist.quote(instrument = "ibm",  start = "1998-01-01")
x <- na.remove(ts.union(spc, ibm))
plot(x, main = "IBM vs S&P 500")
}
}
\keyword{ts}

\eof
\name{ice.river}
\alias{ice.river}
\alias{flow.vat}
\alias{flow.jok}
\alias{prec}
\alias{temp}
\title{
  Icelandic River Data
}
\description{
  Contains the Icelandic river data as presented in Tong (1990),
  pages 432--440.
}
\usage{
data(ice.river)
}
\format{
  4 univariate time series \code{flow.vat}, \code{flow.jok},
  \code{prec}, and \code{temp}, each with 1095 observations and the
  joint series \code{ice.river}.
} 
\details{
  The series are daily observations from Jan. 1, 1972 to Dec. 31, 1974
  on 4 variables: \code{flow.vat}, mean daily flow of Vatnsdalsa river
  (cms), \code{flow.jok}, mean daily flow of Jokulsa Eystri river (cms),
  \code{prec}, daily precipitation in Hveravellir (mm), and mean daily
  temperature in Hveravellir (deg C).

  These datasets were introduced into the literature in a paper by
  Tong, Thanoon, and Gudmundsson (1985).
}
\source{
  Time Series Data Library:
  \url{http://www-personal.buseco.monash.edu.au/~hyndman/TSDL/}
}
\references{
  H. Tong (1990):
  \emph{Non-Linear Time Series, A Dynamical System Approach}.
  Oxford University Press, Oxford.

  H. Tong, B. Thanoon, and G. Gudmundsson (1985):
  Threshold time series modelling of two Icelandic riverflow
  systems.
  \emph{Water Resources Bulletin}, \bold{21}, 651--661.
}
\keyword{datasets}

\eof
\name{irts-functions}
\alias{irts-functions}
\alias{approx.irts}
\alias{daysecond}
\alias{is.businessday}
\alias{is.weekend}
\alias{read.irts}
\alias{weekday}
\alias{write.irts}
\title{Basic Functions for Irregular Time-Series Objects}
\description{
  Basic functions related to irregular time-series objects.
}
\usage{
daysecond(object, tz = "GMT")
approx.irts(object, time, \dots)
is.businessday(object, tz = "GMT")
is.weekend(object, tz = "GMT")
read.irts(file, format = "\%Y-\%m-\%d \%H:\%M:\%S", tz = "GMT", \dots)
weekday(object, tz = "GMT")
write.irts(object, file = "", append = FALSE, quote = FALSE,
           sep = " ", eol = "\n", na = "NA", dec = ".",
           row.names = FALSE, col.names = FALSE, qmethod = "escape",
           format = "\%Y-\%m-\%d \%H:\%M:\%S", tz = "GMT", usetz = FALSE,
           format.value = NULL, \dots)
}
\arguments{
  \item{object}{an object of class \code{"irts"}; usually, a result 
    of a call to \code{\link{irts}}.}
  \item{format, tz, usetz}{formatting related arguments, see
    \code{\link{format.POSIXct}}.} 
  \item{time}{an object of class \code{"POSIXct"} specifying the times
    at which to interpolate the irregularly spaced time-series.}
  \item{file, append, quote, sep, eol, na, dec, row.names, col.names,
    qmethod}{reading and writing related arguments, see
    \code{\link{read.table}} and \code{\link{write.table}}.}
  \item{format.value}{a string which specifies the formatting of the
    values when writing an irregular time-series object to a
    file. \code{format.value} is passed unchanged as argument
    \code{format} to the function \code{\link{formatC}}.} 
  \item{\dots}{further arguments passed to or from other methods: for
    \code{approx.irts} passed to \code{\link{approx}}; for
    \code{read.irts} passed to \code{\link{read.table}}; for
    \code{write.irts} passed to \code{\link{data.frame}}.}
}
\details{
  \code{daysecond} and \code{weekday} return the number of seconds since
  midnight (the same day) and the weekday as a decimal number (0-6,
  Sunday is 0), respectively.

  \code{is.businessday} and \code{is.weekend} test which entries of an
  irregular time-series object are recorded on business days and
  weekends, respectively. 

  \code{approx.irts} interpolates an irregularly spaced time-series at
  prespecified times.

  \code{read.irts} is the function to read irregular time-series
  objects from a file.
  
  \code{write.irts} is the function to write irregular time-series
  objects to a file.
}
\value{
  For \code{daysecond} and \code{weekday} a vector of decimal numbers
  representing the number of seconds and the weekday, respectively.

  For \code{is.businessday} and \code{is.weekend} a vector of
  \code{"logical"} representing the test results for each time.

  For \code{approx.irts}, \code{read.irts} and \code{write.irts} an
  object of class \code{"irts"}.
}
\author{
  A. Trapletti
}
\seealso{
  \code{\link{irts}},
  \code{\link{irts-methods}}
}
\examples{
n <- 10
t <- cumsum(rexp(n, rate = 0.1))
v <- rnorm(n)
x <- irts(t, v)

daysecond(x)
weekday(x)
is.businessday(x)
is.weekend(x)
x

approx.irts(x, seq(ISOdatetime(1970, 1, 1, 0, 0, 0, tz = "GMT"),
            by = "10 secs", length = 7), rule = 2)

\dontrun{
file <- tempfile()

# To write an irregular time-series object to a file one might use
write.irts(x, file = file)

# To read an irregular time-series object from a file one might use
read.irts(file = file)

unlink(file)
}
}
\keyword{ts}

\eof
\name{irts-methods}
\alias{irts-methods}
\alias{lines.irts}
\alias{plot.irts}
\alias{points.irts}
\alias{print.irts}
\alias{time.irts}
\alias{value}
\alias{value.irts}
\alias{[.irts}
\title{Methods for Irregular Time-Series Objects}
\description{
  Methods for irregular time-series objects.
}
\usage{
\method{lines}{irts}(x, type = "l", \dots)
\method{plot}{irts}(x, type = "l", plot.type = c("multiple", "single"), 
     xlab = "Time", ylab = NULL, main = NULL, ylim = NULL,
     oma = c(6, 0, 5, 0), \dots)
\method{points}{irts}(x, type = "p", \dots)                    
\method{print}{irts}(x, format = "\%Y-\%m-\%d \%H:\%M:\%S", tz = "GMT",
      usetz = TRUE, format.value = NULL, \dots)
\method{time}{irts}(x, \dots)
\method{value}{irts}(x, \dots)
x[i]
x[i, j]
x[i, j, \dots]
}
\arguments{
  \item{x}{an object of class \code{"irts"}; usually, a result 
    of a call to \code{\link{irts}}.}
  \item{type, plot.type, xlab, ylab, main, ylim, oma}{graphical
    arguments, see \code{\link{plot}}, \code{\link{points}},
    \code{\link{lines}}, \code{\link{par}}, and \code{\link{plot.mts}}.}
  \item{format, tz, usetz}{formatting related arguments, see
    \code{\link{format.POSIXct}}.}
  \item{format.value}{a string which specifies the formatting of the
    values when printing an irregular time-series 
    object. \code{format.value} is passed unchanged as argument
    \code{format} to the function \code{\link{formatC}}.}
  \item{i, j}{indices specifying the parts to extract from an irregular
    time-series object.}
  \item{\dots}{further arguments passed to or from other methods: for
    \code{lines} passed to \code{\link{lines}}; for \code{plot} passed
    to \code{\link{plot}}, \code{\link{plot.default}}, and
    \code{\link{mtext}}; for \code{points} passed to
    \code{\link{points}}; for \code{print} passed to
    \code{\link{formatC}}; for \code{time}, \code{value}, and
    \code{[.irts} unused.} 
}
\details{
  \code{plot} is the method for plotting irregular time-series objects.

  \code{points} and \code{lines} are the methods for drawing a sequence
  of points as given by an irregular time-series object and joining the
  corresponding points with line segments, respectively.

  \code{print} is the method for printing irregular time-series objects.

  \code{time} and \code{value} are the methods for extracting the
  sequence of times and the sequence of values of an irregular
  time-series object.
  
  \code{[.irts} is the method for extracting parts of irregular
  time-series objects. 
}
\value{
  For \code{time} an object of class \code{"POSIXct"} representing the
  sequence of times. For \code{value} a vector or matrix representing
  the sequence of values. 

  For \code{[.irts} an object of class \code{"irts"} representing the
  extracted part.
  
  For \code{plot}, \code{points}, \code{lines}, and \code{print} the
  irregular time-series object. 
}
\author{
  A. Trapletti
}
\seealso{
  \code{\link{irts}},
  \code{\link{irts-functions}}
}
\examples{
n <- 10
t <- cumsum(rexp(n, rate = 0.1))
v <- rnorm(n)
x <- irts(t, v)

x
time(x)
value(x)
plot(x)
points(x)

t <- cumsum(c(t[1], rexp(n-1, rate = 0.2)))
v <- rnorm(n, sd = 0.1)
x <- irts(t, v)

lines(x, col = "red")
points(x, col = "red")

# Multivariate
t <- cumsum(rexp(n, rate = 0.1))
u <- rnorm(n)
v <- rnorm(n)
x <- irts(t, cbind(u, v))

x
x[,1]
x[1:3,]
x[1:3,1]
plot(x)
}
\keyword{ts}

\eof
\name{irts}
\alias{irts}
\alias{is.irts}
\alias{as.irts}
\title{Irregularly Spaced Time-Series}
\description{
  The function \code{irts} is used to create irregular time-series
  objects.  

  \code{as.irts} coerces an object to an irregularly spaced
  time-series. \code{is.irts} tests whether an object is an irregularly
  spaced time series. 
}
\usage{
irts(time, value)
as.irts(object)
is.irts(object)
}
\arguments{
  \item{time}{a numeric vector or a vector of class \code{"POSIXct"}
    representing the time-stamps of the irregular time-series
    object. The elements of the numeric vector are construed as the
    (signed) number of seconds since the beginning of 1970, see
    \code{\link{POSIXct}}.} 
  \item{value}{a numeric vector or matrix representing the values of the
    irregular time-series object.}
  \item{object}{an R object to be coerced to an irregular time-series
    object or an R object to be tested whether it is an irregular
    time-series object.} 
}
\details{
  The function \code{irts} is used to create irregular time-series
  objects. These are scalar or vector valued time series indexed by a
  time-stamp of class \code{"POSIXct"}. Unlike objects of class
  \code{"ts"}, they can be used to represent irregularly spaced
  time-series.
}
\value{
  A list of class \code{"irts"} with the following elements:
  \item{time}{a vector of class \code{"POSIXct"}.}
  \item{value}{a numeric vector or matrix.}
}
\author{
  A. Trapletti
}
\seealso{
  \code{\link{ts}},
  \code{\link{POSIXct}},
  \code{\link{irts-methods}},
  \code{\link{irts-functions}}
}
\examples{
n <- 10
t <- cumsum(rexp(n, rate = 0.1))
v <- rnorm(n)
x <- irts(t, v)
x

as.irts(cbind(t, v))

is.irts(x)

# Multivariate
u <- rnorm(n)
irts(t, cbind(u, v))
}
\keyword{ts}

\eof
\name{jarque.bera.test}
\alias{jarque.bera.test}
\title{Jarque--Bera Test}
\description{
  Tests the null of normality for \code{x} using the Jarque-Bera
  test statistic.
}
\usage{
jarque.bera.test(x)
}
\arguments{
  \item{x}{a numeric vector or time series.}
}
\details{
  This test is a joint statistic using skewness and kurtosis
  coefficients.
  
  Missing values are not allowed.
}
\value{
  A list with class \code{"htest"} containing the following components:
  \item{statistic}{the value of the test statistic.}
  \item{parameter}{the degrees of freedom.}
  \item{p.value}{the p-value of the test.}
  \item{method}{a character string indicating what type of test was
    performed.} 
  \item{data.name}{a character string giving the name of the data.}
}
\references{
  J. B. Cromwell, W. C. Labys and M. Terraza (1994):
  \emph{Univariate Tests for Time Series Models},
  Sage, Thousand Oaks, CA, pages 20--22.
}
\author{A. Trapletti}
\examples{
x <- rnorm(100)  # null
jarque.bera.test(x)

x <- runif(100)  # alternative
jarque.bera.test(x)
}
\keyword{ts}

\eof
\name{kpss.test}
\alias{kpss.test}
\title{KPSS Test for Stationarity}
\description{
  Computes the Kwiatkowski-Phillips-Schmidt-Shin (KPSS) test for the
  null hypothesis that \code{x} is level or trend stationary.
}
\usage{
kpss.test(x, null = c("Level", "Trend"), lshort = TRUE)
}
\arguments{
  \item{x}{a numeric vector or univariate time series.}
  \item{null}{indicates the null hypothesis and must be one of
    \code{"Level"} (default) or \code{"Trend"}.  You can specify just
    the initial letter.}
  \item{lshort}{a logical indicating whether the short or long version
    of the truncation lag parameter is used.}
}
\details{
  To estimate \code{sigma^2} the Newey-West estimator is used.
  If \code{lshort} is \code{TRUE}, then the truncation lag parameter is
  set to \code{trunc(3*sqrt(n)/13)}, otherwise
  \code{trunc(10*sqrt(n)/14)} is used.  The p-values are interpolated
  from Table 1 of Kwiatkowski et al. (1992). If the computed statistic
  is outside the table of critical values, then a warning message is
  generated.
  
  Missing values are not handled.
}
\value{
  A list with class \code{"htest"} containing the following components:
  \item{statistic}{the value of the test statistic.}
  \item{parameter}{the truncation lag parameter.}
  \item{p.value}{the p-value of the test.}
  \item{method}{a character string indicating what type of test was
    performed.} 
  \item{data.name}{a character string giving the name of the data.}
}
\references{
  D. Kwiatkowski, P. C. B. Phillips, P. Schmidt, and Y. Shin (1992):
  Testing the Null Hypothesis of Stationarity against the Alternative of
  a Unit Root.
  \emph{Journal of Econometrics} \bold{54}, 159--178.
}
\author{A. Trapletti}
\seealso{
  \code{\link{pp.test}}
}
\examples{
x <- rnorm(1000)  # is level stationary
kpss.test(x)

y <- cumsum(x)  # has unit root
kpss.test(y)

x <- 0.3*(1:1000)+rnorm(1000)  # is trend stationary
kpss.test(x, null = "Trend")
}
\keyword{ts}

\eof
\name{maxdrawdown}
\alias{maxdrawdown}
\title{Maximum Drawdown or Maximum Loss}
\description{
  This function computes the maximum drawdown or maximum loss of the
  univariate time series (or vector) \code{x}. 
}
\usage{
maxdrawdown(x)
}
\arguments{
  \item{x}{a numeric vector or univariate time series.}
}
\details{
  The max drawdown or max loss statistic is defined as the maximum
  value drop after one of the peaks of \code{x}. For financial
  instruments the max drawdown represents the worst investment loss for
  a buy-and-hold strategy invested in \code{x}.
}
\value{
  A list containing the following three components:
  \item{maxdrawdown}{double representing the max drawdown or max
    loss statistic.}
  \item{from}{the index (or vector of indices) where the max drawdown
    period starts.} 
  \item{to}{the index (or vector of indices) where the max drawdown
    period ends.} 
}
\author{A. Trapletti}
\seealso{
  \code{\link{sterling}}
}
\examples{
# Toy example
x <- c(1:10, 9:7, 8:14, 13:8, 9:20)
mdd <- maxdrawdown(x)
mdd

plot(x)
segments(mdd$from, x[mdd$from], mdd$to, x[mdd$from], col="grey")
segments(mdd$from, x[mdd$to], mdd$to, x[mdd$to], col="grey")
mid <- (mdd$from + mdd$to)/2
arrows(mid, x[mdd$from], mid, x[mdd$to], col="red", length = 0.16)

# Realistic example
data(EuStockMarkets)
dax <- log(EuStockMarkets[,"DAX"])
mdd <- maxdrawdown(dax)
mdd

plot(dax)
segments(time(dax)[mdd$from], dax[mdd$from],
         time(dax)[mdd$to], dax[mdd$from], col="grey")
segments(time(dax)[mdd$from], dax[mdd$to],
         time(dax)[mdd$to], dax[mdd$to], col="grey")
mid <- time(dax)[(mdd$from + mdd$to)/2]
arrows(mid, dax[mdd$from], mid, dax[mdd$to], col="red", length = 0.16)
}
\keyword{ts}

\eof
\name{na.remove}
\alias{na.remove}
\alias{na.remove.ts}
\alias{na.remove.default}
\title{NA Handling Routines for Time Series}
\description{
  Observations with missing values in some of the variables are
  removed.
}
\usage{
na.remove(object, \dots)
}
\arguments{
  \item{object}{a numeric matrix, vector, univariate, or multivariate
    time series.}
  \item{\dots}{further arguments to be passed to or from methods.}
}
\details{
  For \code{na.remove.ts} this changes the ``intrinsic'' time scale.  It
  is assumed that both, the new and the old time scale are synchronized
  at the first and the last valid observation.  In between, the new
  series is equally spaced in the new time scale.
}
\value{
  An object without missing values.  The attribute \code{"na.removed"}
  contains the indices of the removed missing values in \code{object}.
}
\author{A. Trapletti}
\seealso{
  \code{\link{na.omit}},
  \code{\link{na.fail}}
}
\examples{
x<-ts(c(5453.08,5409.24,5315.57,5270.53, # one and a half week stock index
        5211.66,NA,NA,5160.80,5172.37))  # data including a weekend
na.remove(x)  # eliminate weekend and introduce ``business'' time scale
}
\keyword{ts}

\eof
\name{nino}
\alias{nino}
\alias{nino3}
\alias{nino3.4}
\title{
  Sea Surface Temperature (SST) Nino 3 and Nino 3.4 Indices
}
\description{
  These data constitutes of Nino Region 3 and Nino Region 3.4 SST 
  indices.
}
\usage{
data(nino)
}
\format{
  Two univariate time series \code{nino3} and \code{nino3.4} with 598
  observations and the joint series \code{nino}.
}
\details{
  The measurements are given in degrees Celsius.
  The Nino 3 Region is bounded by 90W-150W and 5S-5N.
  The Nino 3.4 Region is bounded by 120W-170W and 5S-5N.
}
\source{
  Climate Prediction Center:
  \url{http://www.cpc.ncep.noaa.gov/data/indices/}
}
\keyword{datasets}

\eof
\name{plotOHLC}
\alias{plotOHLC}
\title{Plot Open--High--Low--Close Bar Chart}
\description{
  Plots open--high--low--close bar chart of a (financial) time series.
}
\usage{
plotOHLC(x, xlim = NULL, ylim = NULL, xlab = "Time", ylab, col = par("col"),
         bg = par("bg"), axes = TRUE, frame.plot = axes, ann = par("ann"),
         main = NULL, date = c("calendar", "julian"), format = "\%Y-\%m-\%d",
         origin = "1899-12-30", \dots)
}
\arguments{
  \item{x}{a multivariate time series object of class \code{"mts"}.}
  \item{xlim, ylim, xlab, ylab, col, bg, axes, frame.plot, ann,
    main}{graphical arguments, see \code{\link{plot}},
    \code{\link{plot.default}} and \code{\link{par}}.}
  \item{date}{a string indicating the type of x axis
    annotation. Default is calendar dates.}
  \item{format}{a string indicating the format of the x axis annotation if
    \code{date == "calendar"}. For details see
    \code{\link{format.POSIXct}}.} 
  \item{origin}{an R object specifying the origin of the Julian dates
    if \code{date == "calendar"}. Defaults to 1899-12-30 (Popular
    spreadsheet programs internally also use Julian dates with this origin).}
  \item{\dots}{further graphical arguments passed to
    \code{\link{plot.window}}, \code{\link{title}}, \code{\link{axis}},
    and \code{\link{box}}.}
}
\details{
  Within an open--high--low--close bar chart, each bar represents
  price information for the time interval between the open and the close
  price. The left tick for each bar indicates the open price for the
  time interval. The right tick indicates the closing price for the time
  interval. The vertical length of the bar represents the price range
  for the time interval.

  The time scale of \code{x} must be in Julian dates (days since the
  \code{origin}).
}
\author{A. Trapletti}
\seealso{
  \code{\link{plot.default}},
  \code{\link{format.POSIXct}},
  \code{\link{get.hist.quote}}
}
\examples{
\dontrun{
# Plot OHLC bar chart for the last `nDays' days of the instrument `instrument'

nDays <- 50
instrument <- "^spc"

start <- strftime(as.POSIXlt(Sys.time() - nDays*24*3600), format="\%Y-\%m-\%d") 
end <- strftime(as.POSIXlt(Sys.time()), format = "\%Y-\%m-\%d") 
x <- get.hist.quote(instrument = instrument, start = start, end = end)

plotOHLC(x, ylab = "price", main = instrument)
}
}
\keyword{hplot}
\keyword{ts}

\eof
\name{po.test}
\alias{po.test}
\title{Phillips--Ouliaris Cointegration Test}
\description{
  Computes the Phillips-Ouliaris test for the null hypothesis that
  \code{x} is not cointegrated.
}
\usage{
po.test(x, demean = TRUE, lshort = TRUE) 
}
\arguments{
  \item{x}{a matrix or multivariate time series.}
  \item{demean}{a logical indicating whether an intercept is included in
    the cointegration regression or not.}
  \item{lshort}{a logical indicating whether the short or long version
    of the truncation lag parameter is used.}
}
\details{
  The Phillips-Perron Z(alpha) statistic for a unit root in the
  residuals of the cointegration regression is computed, see also
  \code{\link{pp.test}}. The unit root is estimated from a regression of
  the first variable (column) of \code{x} on the remaining variables of
  \code{x} without a constant and a linear trend.  To estimate
  \code{sigma^2} the Newey-West estimator is used.  If \code{lshort} is
  \code{TRUE}, then the truncation lag parameter is set to
  \code{trunc(n/100)}, otherwise \code{trunc(n/30)} is used.  The
  p-values are interpolated from Table Ia and Ib, p. 189 of Phillips and
  Ouliaris (1990).  If the computed statistic is outside the table of
  critical values, then a warning message is generated.
  
  The dimension of \code{x} is restricted to six variables.  Missing
  values are not handled.
}
\value{
  A list with class \code{"htest"} containing the following components:
  \item{statistic}{the value of the test statistic.}
  \item{parameter}{the truncation lag parameter.}
  \item{p.value}{the p-value of the test.}
  \item{method}{a character string indicating what type of test was
    performed.} 
  \item{data.name}{a character string giving the name of the data.}
}
\references{
  P. C. B. Phillips and S. Ouliaris (1990):
  Asymptotic Properties of Residual Based Tests for Cointegration.
  \emph{Econometrica} \bold{58}, 165--193.
}
\author{A. Trapletti}
\seealso{
  \code{\link{pp.test}}
}
\examples{
x <- ts(diffinv(matrix(rnorm(2000),1000,2)))  # no cointegration
po.test(x)

x <- diffinv(rnorm(1000))
y <- 2.0-3.0*x+rnorm(x,sd=5)
z <- ts(cbind(x,y))  # cointegrated
po.test(z)
}
\keyword{ts}

\eof
\name{portfolio.optim}
\alias{portfolio.optim}
\alias{portfolio.optim.ts}
\alias{portfolio.optim.default}
\title{Portfolio Optimization}
\description{
  Computes an efficient portfolio from the given return series \code{x}
  in the mean-variance sense.
}
\usage{
\method{portfolio.optim}{default}(x, pm = mean(x), riskless = FALSE,
                shorts = FALSE, rf = 0.0, reslow = NULL, reshigh = NULL,
                covmat = cov(x), \dots)
}
\arguments{
  \item{x}{a numeric matrix or multivariate time series consisting of a
    series of returns.}
  \item{pm}{the desired mean portfolio return.}
  \item{riskless}{a logical indicating whether there is a riskless
    lending and borrowing rate.}
  \item{shorts}{a logical indicating whether shortsales on the risky
    securities are allowed.} 
  \item{rf}{the riskfree interest rate.}
  \item{reslow}{a vector specifying the (optional) lower bound on
    allowed portfolio weights.}  
  \item{reshigh}{a vector specifying the (optional) upper bound on
    allowed portfolio weights.} 
  \item{covmat}{the covariance matrix of asset returns.}
  \item{\dots}{further arguments to be passed from or to methods.}
}
\details{
  The computed portfolio has the desired expected return \code{pm} and
  no other portfolio exists, which has the same mean return, but a
  smaller variance. Inequality restrictions of the form \eqn{w_l \le w
  \le w_h}{w_l <= w <= w_h} can be imposed using the \code{reslow} and
  \code{reshigh} vectors. An alternative covariance matrix estimate can
  be supplied via the \code{covmat} argument. To solve the quadratic
  program, \code{\link[quadprog]{solve.QP}} is used.

  \code{portfolio.optim} is a generic function with methods for
  multivariate \code{"ts"} and \code{default} for matrix.

  Missing values are not allowed.
}
\value{
  A list containing the following components:
  \item{pw}{the portfolio weights.}
  \item{px}{the returns of the overall portfolio.}
  \item{pm}{the expected portfolio return.}
  \item{ps}{the standared deviation of the portfolio returns.}
}
\references{
  E. J. Elton and M. J. Gruber (1991): \emph{Modern Portfolio Theory and
  Investment Analysis}, 4th Edition, Wiley, NY, pp. 65-93.

  C. Huang and R. H. Litzenberger (1988): \emph{Foundations for
  Financial Economics}, Elsevier, NY, pp. 59-82.
}
\author{A. Trapletti}
\seealso{
  \code{\link[quadprog]{solve.QP}}
}
\examples{
x <- rnorm(1000)
dim(x) <- c(500,2)
res <- portfolio.optim(x)
res$pw
}
\keyword{ts}

\eof
\name{pp.test}
\alias{pp.test}
\title{Phillips--Perron Unit Root Test}
\description{
  Computes the Phillips-Perron test for the null hypothesis that
  \code{x} has a unit root.
}
\usage{
pp.test(x, alternative = c("stationary", "explosive"),
        type = c("Z(alpha)", "Z(t_alpha)"), lshort = TRUE)
}
\arguments{
  \item{x}{a numeric vector or univariate time series.}
  \item{alternative}{indicates the alternative hypothesis and must be
    one of \code{"stationary"} (default) or \code{"explosive"}.  You can
    specify just the initial letter.}
  \item{type}{indicates which variant of the test is computed and must
    be one of \code{"Z(alpha)"} (default) or \code{"Z(t_alpha)"}.}
  \item{lshort}{a logical indicating whether the short or long version
    of the truncation lag parameter is used.}
}
\details{
  The general regression equation which incorporates a constant and a
  linear trend is used and the \code{Z(alpha)} or \code{Z(t_alpha)}
  statistic for a first order autoregressive coefficient equals one are
  computed.  To estimate \code{sigma^2} the Newey-West estimator is
  used.  If \code{lshort} is \code{TRUE}, then the truncation lag
  parameter is set to \code{trunc(4*(n/100)^0.25)}, otherwise
  \code{trunc(12*(n/100)^0.25)} is used.  The p-values are interpolated
  from Table 4.1 and 4.2, p. 103 of Banerjee et al. (1993).  If the
  computed statistic is outside the table of critical values, then a
  warning message is generated.
  
  Missing values are not handled.
}
\value{
  A list with class \code{"htest"} containing the following components:
  \item{statistic}{the value of the test statistic.}
  \item{parameter}{the truncation lag parameter.}
  \item{p.value}{the p-value of the test.}
  \item{method}{a character string indicating what type of test was
    performed.} 
  \item{data.name}{a character string giving the name of the data.}
  \item{alternative}{a character string describing the alternative
    hypothesis.}
}
\references{
  A. Banerjee, J. J. Dolado, J. W. Galbraith, and D. F. Hendry (1993):
  \emph{Cointegration, Error Correction, and the Econometric Analysis
    of Non-Stationary Data}, Oxford University Press, Oxford.
  
  P. Perron (1988):
  Trends and Random Walks in Macroeconomic Time Series.
  \emph{Journal of Economic Dynamics and Control} \bold{12}, 297--332.
}
\author{A. Trapletti}
\seealso{
  \code{\link{adf.test}}
}
\examples{
x <- rnorm(1000)  # no unit-root
pp.test(x)

y <- cumsum(x)  # has unit root
pp.test(y)
}
\keyword{ts}

\eof
\name{quadmap}
\alias{quadmap}
\title{Quadratic Map (Logistic Equation)}
\description{
  Computes the quadratic map simulation.
}
\usage{
quadmap(xi = 0.2, a = 4.0, n = 1000)
}
\arguments{
  \item{xi}{the initial value for the iteration.}
  \item{a}{the quadratic map parameter.}
  \item{n}{the length of the simulated series.}
}
\value{
  A vector containing the simulated series.
}
\author{A. Trapletti}
\examples{
x <- quadmap()
acf(x, 10)
}
\keyword{ts}

\eof
\name{read.matrix}
\alias{read.matrix}
\title{Read Matrix Data}
\description{
  Reads a matrix data file.
}
\usage{
read.matrix(file, header = FALSE, sep = "", skip = 0)
}
\arguments{
  \item{file}{the name of the file which the data are to be read from.}
  \item{header}{a logical value indicating whether the file contains the
    names of the columns as its first line.}
  \item{sep}{the field separator character.  Values on each line of the
    file are separated by this character.}
  \item{skip}{the number of lines of the data file to skip before
    beginning to read data.}
}
\details{
  Usually each row of the file represents an observation and each column
  contains a variable.  The first row possibly contains the names of the
  variables (columns).

  \code{read.matrix} might be more efficient than
  \code{\link{read.table}} for very large data sets.
}
\author{A. Trapletti}
\seealso{
  \code{\link{read.table}}.
}
\examples{
x <- matrix(0, 10, 10)
write(x, "test", ncolumns=10)
x <- read.matrix("test")
x
unlink("test")
}
\keyword{file}
\keyword{ts}

\eof
\name{read.ts}
\alias{read.ts}
\title{Read Time Series Data}
\description{
  Reads a time series file.
}
\usage{
read.ts(file, header = FALSE, sep = "", skip = 0, \dots)
}
\arguments{
  \item{file}{the name of the file which the data are to be read from.
    Each line of the file contains one observation of the variables.}
  \item{header}{a logical value indicating whether the file contains
    the names of the variables as its first line.}
  \item{sep}{the field separator character.  Values on each line of the
    file are separated by this character.}
  \item{skip}{the number of lines of the data file to skip before
    beginning to read data.}
  \item{\dots}{Additional arguments for \code{\link{ts}} such as, e.g.,
    \code{start}.}
}
\details{
  Each row of the file represents an observation and each column
  contains a variable.  The first row possibly contains the names of the
  variables.
}
\author{A. Trapletti}
\seealso{
  \code{\link{ts}}.
}
\examples{
data(sunspots)
st <- start(sunspots)
fr <- frequency(sunspots)
write(sunspots, "sunspots", ncolumns=1)
x <- read.ts("sunspots", start=st, frequency=fr)
plot(x)
unlink("sunspots")
}
\keyword{file}
\keyword{ts}

\eof
\name{runs.test}
\alias{runs.test}
\title{Runs Test}
\description{
  Computes the runs test for randomness of the dichotomous (binary) data
  series \code{x}.
}
\usage{
runs.test(x, alternative = c("two.sided", "less", "greater"))
}
\arguments{
  \item{x}{a dichotomous factor.}
  \item{alternative}{indicates the alternative hypothesis and must be
    one of \code{"two.sided"} (default), \code{"less"}, or
    \code{"greater"}. You can specify just the initial letter.}
}
\details{
  This test searches for randomness in the observed data series
  \code{x} by examining the frequency of runs. A "run" is defined as a
  series of similar responses.

  Note, that by using the alternative \code{"less"} the null of
  randomness is tested against some kind of "under-mixing"
  ("trend"). By using the alternative \code{"greater"} the null of 
  randomness is tested against some kind of "over-mixing"
  ("mean-reversion").  
  
  Missing values are not allowed.
}
\value{
  A list with class \code{"htest"} containing the following components:
  \item{statistic}{the value of the test statistic.}
  \item{p.value}{the p-value of the test.}
  \item{method}{a character string indicating what type of test was
    performed.} 
  \item{data.name}{a character string giving the name of the data.}
  \item{alternative}{a character string describing the alternative
    hypothesis.}
}
\references{
  S. Siegel (1956): \emph{Nonparametric Statistics for the Behavioural
  Sciences}, McGraw-Hill, New York.
  
  S. Siegel and N. J. Castellan (1988): \emph{Nonparametric Statistics for the
  Behavioural Sciences}, 2nd edn, McGraw-Hill, New York.
}
\author{A. Trapletti}
\examples{
x <- factor(sign(rnorm(100)))  # randomness
runs.test(x)

x <- factor(rep(c(-1,1),50))  # over-mixing
runs.test(x)
}
\keyword{ts}

\eof
\name{seqplot.ts}
\alias{seqplot.ts}
\title{Plot Two Time Series}
\description{
  Plot two time series on the same plot frame.
}
\usage{
seqplot.ts(x, y, colx = "black", coly = "red", typex = "l",
           typey = "l", pchx = 1, pchy = 1, ltyx = "solid",
           ltyy = "solid", oma = c(6, 0, 5, 0), ann = par("ann"),
           xlab = "Time", ylab = deparse(substitute(x)), main = NULL)
}

\arguments{
  \item{x, y}{the time series.}
  \item{colx, coly}{color code or name for the \code{x} and \code{y}
    series, see \code{\link{colors}}, \code{\link{palette}}.}
  \item{typex, typey}{what type of plot should be drawn for the \code{x}
    and \code{y} series, see \code{\link{plot}}.}
  \item{pchx, pchy}{character or integer code for kind of points/lines
    for the \code{x} and \code{y} series.}
  \item{ltyx, ltyy}{line type code for the \code{x} and \code{y} series,
    see \code{\link{lines}}.}
  \item{oma}{a vector giving the size of the outer margins in lines of
    text, see \code{\link{par}}.}
  \item{ann}{annotate the plots? See \code{\link{par}}.}
  \item{xlab, ylab}{titles for the x and y axis.}
  \item{main}{an overall title for the plot.}
}
\details{
  Unlike \code{\link{plot.ts}} the series can have different time bases,
  but they should have the same frequency. Unlike \code{\link{ts.plot}}
  the series can be plotted in different styles and for multivariate
  \code{x} and \code{y} the common variables are plotted together in a
  separate array element.
}
\value{
  None.
}
\author{A. Trapletti}
\seealso{
  \code{\link{ts}}, \code{\link{plot.ts}}
}
\examples{
data(USeconomic)
x <- ts.union(log(M1), log(GNP), rs, rl)
m.ar <- ar(x, method = "ols", order.max = 5)
y <- predict(m.ar, x, n.ahead = 200, se.fit = FALSE)
seqplot.ts(x, y)
}
\keyword{hplot}
\keyword{ts}

\eof
\name{sharpe}
\alias{sharpe}
\title{Sharpe Ratio}
\description{
  This function computes the Sharpe ratio of the univariate time series
  (or vector) \code{x}.  
}
\usage{
sharpe(x, r = 0, scale = sqrt(250))
}
\arguments{
  \item{x}{a numeric vector or univariate time series corresponding to a
    portfolio's cumulated returns.}
  \item{r}{the risk free rate. Default corresponds to using portfolio
    returns not in excess of the riskless return.} 
  \item{scale}{a scale factor. Default corresponds to an annualization
    when working with daily financial time series data.}  
}
\details{
  The Sharpe ratio is defined as a portfolio's mean return in excess of
  the riskless return divided by the portfolio's standard deviation. In
  finance the Sharpe Ratio represents a measure of the portfolio's
  risk-adjusted (excess) return. 
}
\value{
  a double representing the Sharpe ratio.
}
\author{A. Trapletti}
\seealso{
  \code{\link{sterling}}
}
\examples{
data(EuStockMarkets)
dax <- log(EuStockMarkets[,"DAX"])
ftse <- log(EuStockMarkets[,"FTSE"])
sharpe(dax)
sharpe(ftse)
}
\keyword{ts}

\eof
\name{sterling}
\alias{sterling}
\title{Sterling Ratio}
\description{
  This function computes the Sterling ratio of the univariate time series
  (or vector) \code{x}.  
}
\usage{
sterling(x)
}
\arguments{
  \item{x}{a numeric vector or univariate time series corresponding to a
    portfolio's cumulated returns.}
}
\details{
  The Sterling ratio is defined as a portfolio's overall return divided
  by the portfolio's \code{\link{maxdrawdown}} statistic. In finance the
  Sterling Ratio represents a measure of the portfolio's risk-adjusted
  return.   
}
\value{
  a double representing the Sterling ratio.
}
\author{A. Trapletti}
\seealso{
  \code{\link{maxdrawdown}}, \code{\link{sharpe}}
}
\examples{
data(EuStockMarkets)
dax <- log(EuStockMarkets[,"DAX"])
ftse <- log(EuStockMarkets[,"FTSE"])
sterling(dax)
sterling(ftse)
}
\keyword{ts}

\eof
\name{summary.arma}
\alias{summary.arma}
\alias{print.summary.arma}
\title{Summarizing ARMA Model Fits}
\description{
  Methods for creating and printing summaries of ARMA model fits.
}
\usage{
\method{summary}{arma}(object, \dots)
\method{print}{summary.arma}(x, digits = max(3, getOption("digits") - 3),
      signif.stars = getOption("show.signif.stars"), \dots)
}
\arguments{
  \item{object}{an object of class \code{"arma"}; usually, a result of a
    call to \code{\link{arma}}.}
  \item{x}{an object of class \code{"summary.arma"}; usually, a result
    of a call to the summary method for objects of class \code{"arma"}.}
  \item{digits, signif.stars}{see \code{\link{printCoefmat}}.}
  \item{\dots}{further arguments passed to or from other methods.}
}
\details{
  The summary method computes the asymptotic standard errors of the
  coefficient estimates from the numerically differentiated Hessian
  matrix approximation.  The AIC is computed from the conditional
  sum-of-squared errors and not from the true maximum likelihood
  function. That may be problematic.
}
\value{
  A list of class \code{"summary.arma"}.
}
\seealso{
  \code{\link{arma}}
}
\keyword{models}
\keyword{ts}

\eof
\name{summary.garch}
\alias{summary.garch}
\alias{print.summary.garch}
\title{Summarizing GARCH Model Fits}
\description{
  Methods for creating and printing summaries of GARCH model fits.
}
\usage{
\method{summary}{garch}(object, \dots)
\method{print}{summary.garch}(x, digits = max(3, getOption("digits") - 3),
      signif.stars = getOption("show.signif.stars"), \dots)
}
\arguments{
  \item{object}{an object of class \code{"garch"}; usually, a result of a
    call to \code{\link{garch}}.}
  \item{x}{an object of class \code{"summary.garch"}; usually, a result
    of a call to the summary method for objects of class \code{"garch"}.}
  \item{digits, signif.stars}{see \code{\link{printCoefmat}}.}
  \item{\dots}{further arguments passed to or from other methods.}
}
\details{
  \code{summary} computes the asymptotic standard errors of the
  coefficient estimates from an outer-product approximation of the
  Hessian evaluated at the estimates, see Bollerslev (1986).  It
  furthermore tests the residuals for normality and remaining ARCH
  effects, see \code{\link{jarque.bera.test}} and
  \code{\link{Box.test}}. 
}
\value{
  A list of class \code{"summary.garch"}.
}
\references{
  T. Bollerslev (1986):
  Generalized Autoregressive Conditional Heteroscedasticity.
  \emph{Journal of Econometrics} \bold{31}, 307--327.
}
\seealso{
  \code{\link{garch}}
}
\keyword{models}
\keyword{ts}

\eof
\name{surrogate}
\alias{surrogate}
\title{Generate Surrogate Data and Statistics}
\description{
  Generates \code{ns} surrogate samples from the original data \code{x}
  and computes the standard error and the bias of \code{statistic} as in
  a bootstrap setup, if \code{statistic} is given.
}
\usage{
surrogate(x, ns = 1, fft = FALSE, amplitude = FALSE,
          statistic = NULL, \dots)
}
\arguments{
  \item{x}{a numeric vector or time series.}
  \item{ns}{the number of surrogate series to compute.}
  \item{fft}{a logical indicating whether phase randomized surrogate
    data is generated.}
  \item{amplitude}{a logical indicating whether amplitude-adjusted
    surrogate data is computed.}
  \item{statistic}{a function which when applied to a time series
    returns a vector containing the statistic(s) of interest.}
  \item{\dots}{Additional arguments for \code{statistic} which are
    passed unchanged each time it is called.}
}
\details{
  If \code{fft} is \code{FALSE}, then \code{x} is mixed in temporal
  order, so that all temporal dependencies are eliminated, but the
  histogram of the original data is preserved.  If \code{fft} is
  \code{TRUE}, then surrogate data with the same spectrum as \code{x} is
  computed by randomizing the phases of the Fourier coefficients of
  \code{x}.  If in addition \code{amplitude} is \code{TRUE}, then also
  the amplitude distribution of the original series is preserved.

  Note, that the interpretation of the computed standard error and bias
  is different than in a bootstrap setup.

  To compute the phase randomized surrogate and the amplitude adjusted
  data algorithm 1 and 2 from Theiler et al. (1992), pp. 183, 184 are
  used.
  
  Missing values are not allowed.
}
\value{
  If \code{statistic} is \code{NULL}, then it returns a matrix or time
  series with \code{ns} columns and \code{length(x)} rows containing the
  surrogate data. Each column contains one surrogate sample.

  If \code{statistic} is given, then a list of class
  \code{"resample.statistic"} with the following elements is returned:
  \item{statistic}{the results of applying \code{statistic} to each of
    the simulated time series.}
  \item{orig.statistic}{the results of applying \code{statistic} to the
    original series.}
  \item{bias}{the bias of the statistics computed as in a bootstrap
    setup.}
  \item{se}{the standard error of the statistics computed as in a
    bootstrap setup.}
  \item{call}{the original call of \code{surrogate}.}
}
\references{
  J. Theiler, B. Galdrikian, A. Longtin, S. Eubank, and J. D. Farmer
  (1992): Using Surrogate Data to Detect
  Nonlinearity in Time Series, in \emph{Nonlinear Modelling and
  Forecasting}, Eds. M. Casdagli and S. Eubank, Santa Fe Institute,
  Addison Wesley, 163--188.
}
\author{A. Trapletti}
\seealso{
  \code{\link{sample}}, \code{\link{tsbootstrap}}
}
\examples{
x <- 1:10  # Simple example
surrogate(x)

n <- 500  # Generate AR(1) process
e <- rnorm(n)  
x <- double(n)
x[1] <- rnorm(1)
for(i in 2:n) {
  x[i] <- 0.4 * x[i-1] + e[i]
}
x <- ts(x)

theta <- function(x)  # Autocorrelations up to lag 10
  return(acf(x, plot=FALSE)$acf[2:11])

surrogate(x, ns=50, fft=TRUE, statistic=theta) 
}
\keyword{ts}

\eof
\name{tcm}
\alias{tcm}
\alias{tcm1y}
\alias{tcm3y}
\alias{tcm5y}
\alias{tcm10y}
\title{
  Monthly Yields on Treasury Securities
}
\description{
  This data set contains monthly 1 year, 3 year, 5 year, and 10 year
  yields on treasury securities at constant, fixed maturity.
}
\usage{
data(tcm)
}
\format{
  4 univariate time series \code{tcm1y}, \code{tcm3y}, \code{tcm5y}, and
  \code{tcm10y} and the joint series \code{tcm}.
}
\details{
  The yields at constant fixed maturity have been constructed by the
  Treasury Department, based on the most actively traded marketable
  treasury securities.
}
\source{
  U.S. Fed \url{http://www.federalreserve.gov/Releases/H15/data.htm}
}
\keyword{datasets}

\eof
\name{tcmd}
\alias{tcmd}
\alias{tcm1yd}
\alias{tcm3yd}
\alias{tcm5yd}
\alias{tcm10yd}
\title{
  Daily Yields on Treasury Securities
}
\description{
  This data set contains daily 1 year, 3 year, 5 year, and 10 year
  yields on treasury securities at constant, fixed maturity.
}
\usage{
data(tcmd)
}
\format{
  4 univariate time series \code{tcm1yd}, \code{tcm3yd}, \code{tcm5yd},
  and \code{tcm10yd} and the joint series \code{tcmd}.
}
\details{
  The yields at constant fixed maturity have been constructed by the
  Treasury Department, based on the most actively traded marketable
  treasury securities.

  Daily refers to business days, i.e., weekends and holidays are
  eliminated.
}
\source{
  U.S. Fed \url{http://www.federalreserve.gov/Releases/H15/data.htm}
}
\keyword{datasets}

\eof
\name{terasvirta.test}
\title{Teraesvirta Neural Network Test for Nonlinearity}
\alias{terasvirta.test}
\alias{terasvirta.test.ts}
\alias{terasvirta.test.default}
\description{
  Generically computes Teraesvirta's neural network test for neglected
  nonlinearity either for the time series \code{x} or the regression
  \code{y~x}.
}
\usage{
\method{terasvirta.test}{ts}(x, lag = 1, type = c("Chisq","F"),
                scale = TRUE, \dots)
\method{terasvirta.test}{default}(x, y, type = c("Chisq","F"),
                scale = TRUE, \dots)
}
\arguments{
  \item{x}{a numeric vector, matrix, or time series.}
  \item{y}{a numeric vector.}
  \item{lag}{an integer which specifies the model order in terms of
    lags.} 
  \item{type}{a string indicating whether the Chi-Squared test or the
    F-test is computed. Valid types are \code{"Chisq"} and \code{"F"}.}
  \item{scale}{a logical indicating whether the data should be scaled 
    before computing the test statistic. The default arguments to
    \code{\link{scale}} are used.}
  \item{\dots}{further arguments to be passed from or to methods.}
}
\details{
  The null is the hypotheses of linearity in
  ``mean''. This test uses a Taylor series expansion of the activation
  function to arrive at a suitable test statistic. If \code{type} equals
  \code{"F"}, then the F-statistic instead of the Chi-Squared statistic
  is used in analogy to the classical linear regression. 
  
  Missing values are not allowed.
}
\value{
  A list with class \code{"htest"} containing the following components:
  \item{statistic}{the value of the test statistic.}
  \item{p.value}{the p-value of the test.}
  \item{method}{a character string indicating what type of test was
    performed.}
  \item{parameter}{a list containing the additional parameters used to
    compute the test statistic.}
  \item{data.name}{a character string giving the name of the data.}
  \item{arguments}{additional arguments used to compute the test statistic.}
}
\references{
  T. Teraesvirta, C. F. Lin, and C. W. J. Granger (1993): Power of the
  Neural Network Linearity Test. \emph{Journal of Time Series Analysis}
  14, 209-220.
}
\author{A. Trapletti}
\seealso{
  \code{\link{white.test}}
}
\examples{
n <- 1000

x <- runif(1000, -1, 1)  # Non-linear in ``mean'' regression 
y <- x^2 - x^3 + 0.1*rnorm(x)
terasvirta.test(x, y)

## Is the polynomial of order 2 misspecified?
terasvirta.test(cbind(x,x^2,x^3), y)

## Generate time series which is nonlinear in ``mean''
x[1] <- 0.0
for(i in (2:n)) {
  x[i] <- 0.4*x[i-1] + tanh(x[i-1]) + rnorm(1, sd=0.5)
}
x <- as.ts(x)
plot(x)
terasvirta.test(x)
}
\keyword{ts}

\eof
\name{tsbootstrap}
\alias{tsbootstrap}
\alias{print.resample.statistic}
\title{Bootstrap for General Stationary Data}
\description{
  \code{tsbootstrap} generates bootstrap samples for general stationary
  data and computes the bootstrap estimate of standard error and bias
  if a statistic is given.
}
\usage{
tsbootstrap(x, nb = 1, statistic = NULL, m = 1, b = NULL,
            type = c("stationary","block"), \dots)
}
\arguments{
  \item{x}{a numeric vector or time series giving the original data.}
  \item{nb}{the number of bootstrap series to compute.}
  \item{statistic}{a function which when applied to a time series
    returns a vector containing the statistic(s) of interest.}
  \item{m}{the length of the basic blocks in the block of blocks
    bootstrap.} 
  \item{b}{if \code{type} is \code{"stationary"}, then \code{b} is the
    mean block length. If \code{type} is \code{"block"}, then \code{b}
    is the fixed block length.}
  \item{type}{the type of bootstrap to generate the simulated time
    series. The possible input values are \code{"stationary"}
    (stationary bootstrap with mean block length \code{b}) and
    \code{"block"} (blockwise bootstrap with block length
    \code{b}). Default to \code{"stationary"}.} 
  \item{\dots}{additional arguments for \code{statistic} which are
    passed unchanged each time \code{statistic} is called.}
}
\details{
  If \code{type} is \code{"stationary"}, then the stationary
  bootstrap scheme with mean block length \code{b} according to Politis
  and Romano (1994) is computed. For \code{type} equals \code{"block"},
  the blockwise bootstrap with block length \code{b} according to
  Kuensch (1989) is used. 

  If \code{m > 1}, then the block of blocks bootstrap is computed
  (see Kuensch, 1989). The basic sampling scheme is the same as for 
  the case \code{m = 1}, except that the bootstrap is applied to a series
  \code{y} containing blocks of length \code{m}, where each block of \code{y} is
  defined as \eqn{y[t] = (x[t], \dots, x[t-m+1])}. Therefore, for the block
  of blocks bootstrap the first argument of \code{statistic} is given by
  a \code{n x m} matrix \code{yb}, where each row of \code{yb} contains one
  bootstrapped basic block observation \eqn{y[t]} (\code{n} is the number of
  observations in \code{x}). 

  Note, that for statistics which are functions of the empirical
  \code{m}-dimensional marginal (\code{m > 1}) only this procedure
  yields asymptotically valid bootstrap estimates. The 
  case \code{m = 1} may only be used for symmetric statistics (i.e., for
  statistics which are invariant under permutations of \code{x}).
  \code{\link{tsboot}} does not implement the block of blocks
  bootstrap, and, therefore, the first example in \code{\link{tsboot}}
  yields inconsistent estimates.
  
  For consistency, the (mean) block length \code{b} should grow with
  \code{n} at an appropriate rate. If \code{b} is not given, then a
  default growth rate of \code{const * n^(1/3)} is used. This rate is
  "optimal" under certain conditions (see the references for more
  details). However, in general the growth rate depends on the specific
  properties of the data generation process. A default value for
  \code{const} has been determined by a Monte Carlo simulation using a
  Gaussian AR(1) process (AR(1)-parameter of 0.5, 500
  observations). \code{const} has been chosen such that the mean square
  error for the bootstrap estimate of the variance of the empirical mean
  is minimized.  

  Note, that the computationally intensive parts are fully implemented
  in \code{C} which makes \code{tsbootstrap} about 10 to 30 times faster
  than \code{\link{tsboot}}.  
  
  Missing values are not allowed.

  There is a special print method for objects of class
  \code{"resample.statistic"} which by default uses
  \code{max(3, getOption("digits") - 3)} digits to format real numbers.
}
\value{
  If \code{statistic} is \code{NULL}, then it returns a matrix or time
  series with \code{nb} columns and \code{length(x)} rows containing the
  bootstrap data. Each column contains one bootstrap sample.

  If \code{statistic} is given, then a list of class
  \code{"resample.statistic"} with the following elements is returned:
  \item{statistic}{the results of applying \code{statistic} to each of
    the simulated time series.}
  \item{orig.statistic}{the results of applying \code{statistic} to the
    original series.}
  \item{bias}{the bootstrap estimate of the bias of \code{statistic}.}
  \item{se}{the bootstrap estimate of the standard error of \code{statistic}.}
  \item{call}{the original call of \code{tsbootstrap}.}
}
\references{
  H. R. Kuensch (1989):
  The Jackknife and the Bootstrap for General Stationary Observations.
  \emph{The Annals of Statistics} \bold{17}, 1217--1241.

  D. N. Politis and J. P. Romano (1994):
  The Stationary Bootstrap.
  \emph{Journal of the American Statistical Association} \bold{89},
  1303--1313.
}
\author{A. Trapletti}
\seealso{
  \code{\link{sample}},
  \code{\link{surrogate}},
  \code{\link{tsboot}}
}
\examples{
n <- 500  # Generate AR(1) process
a <- 0.6
e <- rnorm(n+100)  
x <- double(n+100)
x[1] <- rnorm(1)
for(i in 2:(n+100)) {
  x[i] <- a * x[i-1] + e[i]
}
x <- ts(x[-(1:100)])

tsbootstrap(x, nb=500, statistic=mean)

# Asymptotic formula for the std. error of the mean
sqrt(1/(n*(1-a)^2))

acflag1 <- function(x)
{
  xo <- c(x[,1], x[1,2])
  xm <- mean(xo)
  return(mean((x[,1]-xm)*(x[,2]-xm))/mean((xo-xm)^2))
}

tsbootstrap(x, nb=500, statistic=acflag1, m=2)

# Asymptotic formula for the std. error of the acf at lag one
sqrt(((1+a^2)-2*a^2)/n)
}
\keyword{ts}

\eof
\name{tseries-internal}
\title{Internal tseries functions}
\alias{ampsurr}
\alias{boot.sample}
\alias{fftsurr}
\description{
  Internal tseries functions.
}
\usage{
ampsurr(x)
boot.sample(x, b, type)
fftsurr(x)
}
\details{
  These are not to be called by the user.
}
\author{A. Trapletti}
\keyword{internal}
\keyword{ts}

\eof
\name{white.test}
\title{White Neural Network Test for Nonlinearity}
\alias{white.test}
\alias{white.test.ts}
\alias{white.test.default}
\description{
  Generically computes the White neural network test for neglected
  nonlinearity either for the time series \code{x} or the regression
  \code{y~x}.
}
\usage{
\method{white.test}{ts}(x, lag = 1, qstar = 2, q = 10, range = 4, 
            type = c("Chisq","F"), scale = TRUE, \dots)
\method{white.test}{default}(x, y, qstar = 2, q = 10, range = 4,
            type = c("Chisq","F"), scale = TRUE, \dots)
}
\arguments{
  \item{x}{a numeric vector, matrix, or time series.}
  \item{y}{a numeric vector.}
  \item{lag}{an integer which specifies the model order in terms of
    lags.} 
  \item{q}{an integer representing the number of phantom hidden units
    used to compute the test statistic.}
  \item{qstar}{the test is conducted using \code{qstar} principal
    components of the phantom hidden units. The first principal
    component is omitted since in most cases it appears to be collinear
    with the input vector of lagged variables. This strategy preserves
    power while still conserving degrees of freedom.}
  \item{range}{the input to hidden unit weights are initialized uniformly
    over [-range/2, range/2].}
  \item{type}{a string indicating whether the Chi-Squared test or the
    F-test is computed. Valid types are \code{"Chisq"} and \code{"F"}.}
  \item{scale}{a logical indicating whether the data should be scaled 
    before computing the test statistic. The default arguments to
    \code{\link{scale}} are used.}
  \item{\dots}{further arguments to be passed from or to methods.}
}
\details{
  The null is the hypotheses of linearity in ``mean''. This
  type of test is consistent against arbitrary nonlinearity
  in mean. If \code{type} equals \code{"F"}, then the F-statistic
  instead of the Chi-Squared statistic is used in analogy to the
  classical linear regression. 
  
  Missing values are not allowed.
}
\value{
  A list with class \code{"htest"} containing the following components:
  \item{statistic}{the value of the test statistic.}
  \item{p.value}{the p-value of the test.}
  \item{method}{a character string indicating what type of test was
    performed.}
  \item{parameter}{a list containing the additional parameters used to
    compute the test statistic.}
  \item{data.name}{a character string giving the name of the data.}
  \item{arguments}{additional arguments used to compute the test statistic.}
}
\references{
  T. H. Lee, H. White, and C. W. J. Granger (1993): Testing for
  neglected nonlinearity in time series models. \emph{Journal of
  Econometrics} \bold{56}, 269-290.
}
\author{A. Trapletti}
\seealso{
  \code{\link{terasvirta.test}}
}
\examples{
n <- 1000

x <- runif(1000, -1, 1)  # Non-linear in ``mean'' regression 
y <- x^2 - x^3 + 0.1*rnorm(x)
white.test(x, y)

## Is the polynomial of order 2 misspecified?
white.test(cbind(x,x^2,x^3), y)

## Generate time series which is nonlinear in ``mean''
x[1] <- 0.0
for(i in (2:n)) {
  x[i] <- 0.4*x[i-1] + tanh(x[i-1]) + rnorm(1, sd=0.5)
}
x <- as.ts(x)
plot(x)
white.test(x)
}
\keyword{ts}

\eof
